<?php

namespace App\Admin\Controllers;

use App\Models\UserReportModel;
use App\Models\UsersReport;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Show;
use Dcat\Admin\Http\Controllers\AdminController;

class UsersReportController extends AdminController
{
    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        $grid = new Grid(new UserReportModel());
        $grid->model()->orderByDesc('id');

        $grid->column('id')->sortable();
        $grid->column('user_id');
        $grid->column('report_id');
        $grid->column('type');
        $grid->column('content');
        $grid->column('info');
        $grid->column('img_url');
        $grid->column('status');
        $grid->column('created_at');
        $grid->column('updated_at')->sortable();

        $grid->filter(function (Grid\Filter $filter) {
            $filter->equal('id');

        });
        return $grid;
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     *
     * @return Show
     */
    protected function detail($id)
    {
        return Show::make($id, new UserReportModel(), function (Show $show) {
            $show->field('id');
            $show->field('user_id');
            $show->field('report_id');
            $show->field('type');
            $show->field('content');
            $show->field('info');
            $show->field('img_url');
            $show->field('status');
            $show->field('created_at');
            $show->field('updated_at');
        });
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        return Form::make(new UserReportModel(), function (Form $form) {
            $form->display('id');
            $form->text('user_id');
            $form->text('report_id');
            $form->text('type');
            $form->text('content');
            $form->text('info');
            $form->text('img_url');
            $form->text('status');

            $form->display('created_at');
            $form->display('updated_at');
        });
    }
}
